.. index::
   single: Monte Carlo; Observers

.. module:: mchammer.observers

.. _observers:

Observers
=========


.. index::
   single: Class reference; SiteOccupancyObserver
   single: Monte Carlo; Site occupancy observer

SiteOccupancyObserver
---------------------

.. autoclass:: SiteOccupancyObserver
   :members:
   :undoc-members:
   :inherited-members:


.. index::
   single: Class reference; BinaryShortRangeOrderObserver
   single: Monte Carlo; Short-range order observer

BinaryShortRangeOrderObserver
-----------------------------

.. autoclass:: BinaryShortRangeOrderObserver
   :members:
   :undoc-members:
   :inherited-members:


.. index::
   single: Class reference; StructureFactorObserver
   single: Monte Carlo; Structure factor observer

StructureFactorObserver
-----------------------

.. autoclass:: StructureFactorObserver
   :members:
   :undoc-members:
   :inherited-members:

ClusterCountObserver
--------------------

.. autoclass:: ClusterCountObserver
   :members:
   :undoc-members:
   :inherited-members:


.. index::
   single: Class reference; ClusterExpansionObserver
   single: Monte Carlo; Cluster expansion observer

ClusterExpansionObserver
------------------------

.. autoclass:: ClusterExpansionObserver
   :members:
   :undoc-members:
   :inherited-members:


.. index::
   single: Class reference; ConstituentStrainObserver
   single: Monte Carlo; Constituent strain observer

ConstituentStrainObserver
-------------------------

.. autoclass:: ConstituentStrainObserver
   :members:
   :undoc-members:
   :inherited-members:
